@@ -64,6 +64,8 @@ MainWindow::MainWindow(QWidget *)
 {
     setupActions();
     setAcceptDrops(true);
+    // Ark doesn't provide a fullscreen mode; remove the corresponding window button
+    setWindowFlags(windowFlags() & ~Qt::WindowFullscreenButtonHint);
 }
 
 MainWindow::~MainWindow()
@@ -151,7 +153,8 @@ bool MainWindow::loadPart()
     m_part->setObjectName(QStringLiteral("ArkPart"));
     setCentralWidget(m_part->widget());
 
-    setupGUI(ToolBar | Keys | Save, QStringLiteral("arkui.rc"));
+    setXMLFile(QStringLiteral("arkui.rc"));
+    setupGUI(ToolBar | Keys | Save);
     createGUI(m_part);
 
     statusBar()->hide();
@@ -255,6 +258,10 @@ void MainWindow::quit()
 
 void MainWindow::showSettings()
 {
+    if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
+        return;
+    }
+
     Interface *iface = qobject_cast<Interface*>(m_part);
     Q_ASSERT(iface);
 
