@@ -59,6 +59,13 @@ void ArchiveView::startDrag(Qt::DropActions supportedActions)
     QTreeView::startDrag(supportedActions);
 }
 
+void ArchiveView::expandIfSingleFolder()
+{
+    if (model()->rowCount() == 1) {
+        expandToDepth(0);
+    }
+}
+
 void ArchiveView::setDropsEnabled(bool enabled)
 {
     setAcceptDrops(enabled);
@@ -145,6 +152,15 @@ void ArchiveView::keyPressEvent(QKeyEvent *event)
     }
 }
 
+void ArchiveView::renameSelectedEntry()
+{
+    QModelIndex currentIndex = selectionModel()->currentIndex();
+    currentIndex = (currentIndex.parent().isValid())
+                   ? currentIndex.parent().child(currentIndex.row(), 0)
+                   : model()->index(currentIndex.row(), 0);
+    openEntryEditor(currentIndex);
+}
+
 void ArchiveView::openEntryEditor(const QModelIndex &index)
 {
     m_editorIndex = index;
