@@ -52,6 +52,7 @@
 #include <KJobWidgets>
 #include <KIO/StatJob>
 #include <KMessageBox>
+#include <KParts/OpenUrlArguments>
 #include <KPluginFactory>
 #include <KRun>
 #include <KSelectAction>
@@ -81,8 +82,6 @@
 
 using namespace Kerfuffle;
 
-K_PLUGIN_FACTORY_WITH_JSON(Factory, "ark_part.json", registerPlugin<Ark::Part>();)
-
 namespace Ark
 {
 
@@ -215,6 +214,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
             this, &Part::setReadyGui);
     connect(this, static_cast<void (KParts::ReadOnlyPart::*)()>(&KParts::ReadOnlyPart::completed),
             this, &Part::setFileNameFromArchive);
+    connect(ArkSettings::self(), &KCoreConfigSkeleton::configChanged, this, &Part::updateActions);
 
     m_statusBarExtension = new KParts::StatusBarExtension(this);
 
@@ -407,7 +407,7 @@ void Part::setupActions()
     m_renameFileAction->setText(i18n("&Rename"));
     actionCollection()->setDefaultShortcut(m_renameFileAction, Qt::Key_F2);
     m_renameFileAction->setToolTip(i18nc("@info:tooltip", "Click to rename the selected file"));
-    connect(m_renameFileAction, &QAction::triggered, this, &Part::slotEditFileName);
+    connect(m_renameFileAction, &QAction::triggered, m_view, &ArchiveView::renameSelectedEntry);
 
     m_deleteFilesAction = actionCollection()->addAction(QStringLiteral("delete"));
     m_deleteFilesAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-remove")));
@@ -474,7 +474,7 @@ void Part::setupActions()
 
 void Part::updateActions()
 {
-    bool isWritable = m_model->archive() && !m_model->archive()->isReadOnly();
+    const bool isWritable = isArchiveWritable();
     const Archive::Entry *entry = m_model->entryForIndex(m_filterModel->mapToSource(m_view->selectionModel()->currentIndex()));
     int selectedEntriesCount = m_view->selectionModel()->selectedRows().count();
 
@@ -606,6 +606,11 @@ void Part::slotTestArchive()
     job->start();
 }
 
+bool Part::isArchiveWritable() const
+{
+    return isReadWrite() && m_model->archive() && !m_model->archive()->isReadOnly();
+}
+
 void Part::createArchive()
 {
     const QString fixedMimeType = arguments().metaData()[QStringLiteral("fixedMimeType")];
@@ -893,8 +898,8 @@ void Part::slotLoadingFinished(KJob *job)
 
     // After loading all files, resize the columns to fit all fields
     m_view->header()->resizeSections(QHeaderView::ResizeToContents);
-    // Now we can start accepting drops in the archive view.
-    m_view->setDropsEnabled(true);
+    // Now we can start accepting drops in the archive view (if loading was successful and the archive can be modified).
+    m_view->setDropsEnabled(!job->error() && isArchiveWritable());
 
     updateActions();
 
@@ -964,8 +969,6 @@ void Part::setFileNameFromArchive()
 
 void Part::slotOpenEntry(int mode)
 {
-    qCDebug(ARK) << "Opening with mode" << mode;
-
     QModelIndex index = m_filterModel->mapToSource(m_view->selectionModel()->currentIndex());
     Archive::Entry *entry = m_model->entryForIndex(index);
 
@@ -974,6 +977,12 @@ void Part::slotOpenEntry(int mode)
         return;
     }
 
+    // Don't open files bigger than the size limit.
+    const int maxPreviewSize = ArkSettings::previewFileSizeLimit() * 1024 * 1024;
+    if (ArkSettings::limitPreviewFileSize() && entry->property("size").toLongLong() >= maxPreviewSize) {
+        return;
+    }
+
     // We don't support opening symlinks.
     if (!entry->property("link").toString().isEmpty()) {
         displayMsgWidget(KMessageWidget::Information, i18n("Ark cannot open symlinks."));
@@ -982,7 +991,7 @@ void Part::slotOpenEntry(int mode)
 
     // Extract the entry.
     if (!entry->fullPath().isEmpty()) {
-
+        qCDebug(ARK) << "Opening with mode" << mode;
         m_openFileMode = static_cast<OpenFileMode>(mode);
         KJob *job = nullptr;
 
@@ -1011,19 +1020,14 @@ void Part::slotOpenExtractedEntry(KJob *job)
         m_tmpExtractDirList << openJob->tempDir();
 
         const QString fullName = openJob->validatedFilePath();
-
-        bool isWritable = m_model->archive() && !m_model->archive()->isReadOnly();
-
-        // If archive is readonly set temporarily extracted file to readonly as
-        // well so user will be notified if trying to modify and save the file.
-        if (!isWritable) {
-            QFile::setPermissions(fullName, QFileDevice::ReadOwner | QFileDevice::ReadGroup | QFileDevice::ReadOther);
-        }
-
-        if (isWritable) {
+        if (isArchiveWritable()) {
             m_fileWatcher = new QFileSystemWatcher;
             connect(m_fileWatcher, &QFileSystemWatcher::fileChanged, this, &Part::slotWatchedFileModified);
             m_fileWatcher->addPath(fullName);
+        } else {
+            // If archive is readonly set temporarily extracted file to readonly as
+            // well so user will be notified if trying to modify and save the file.
+            QFile::setPermissions(fullName, QFileDevice::ReadOwner | QFileDevice::ReadGroup | QFileDevice::ReadOther);
         }
 
         if (qobject_cast<OpenWithJob*>(job)) {
@@ -1410,15 +1414,6 @@ void Part::slotAddFiles()
     delete dlg;
 }
 
-void Part::slotEditFileName()
-{
-    QModelIndex currentIndex = m_view->selectionModel()->currentIndex();
-    currentIndex = (currentIndex.parent().isValid())
-                   ? currentIndex.parent().child(currentIndex.row(), 0)
-                   : m_model->index(currentIndex.row(), 0);
-    m_view->openEntryEditor(currentIndex);
-}
-
 void Part::slotCutFiles()
 {
     QModelIndexList selectedRows = addChildren(getSelectedIndexes());
